-- ───────────────────────────────────────────────────────────────────
--          ╭───────────────────────────────────────────────╮
--          │               LSP Configuration               │
--          ╰───────────────────────────────────────────────╯
return {
    -- lsp configuration
    "neovim/nvim-lspconfig",
    event = { "BufReadPre", "BufNewFile" },
    dependencies = {
        "hrsh7th/cmp-nvim-lsp",
        { "antosha417/nvim-lsp-file-operations", config = true },
        "mfussenegger/nvim-jdtls",
    },
    config = function()
        local enable = vim.lsp.enable

        -- Change the Diagnostic symbols in the sign column (gutter)
        local signs = { Error = "󰅚 ", Warn = "󰀪 ", Hint = "󰌶", Info = "󰋽 " }
        for type, icon in pairs(signs) do
            local hl = "DiagnosticSign" .. type
            vim.fn.sign_define(hl, { text = icon, texthl = hl, numhl = "" })
        end

        -- ───────────────────────────────────────────────────────────────────
        --          ╭───────────────────────────────────────────────╮
        --          │        Import configs from other files        │
        --          ╰───────────────────────────────────────────────╯
        require("plugins.lsp.ls.bashls")
        require("plugins.lsp.ls.c")
        require("plugins.lsp.ls.go")
        require("plugins.lsp.ls.hypr")
        require("plugins.lsp.ls.low-level")
        require("plugins.lsp.ls.luals")
        require("plugins.lsp.ls.pyright")
        require("plugins.lsp.ls.rust-analyzer")
        require("plugins.lsp.ls.ruby")
        require("plugins.lsp.ls.text")
        require("plugins.lsp.ls.web")
        -- ───────────────────────────────────────────────────────────────────
    end,
}
-- ───────────────────────────────────────────────────────────────────
